import Vue from "vue";

/* 印刷平台-API */
export const PRINT_API = "/api/ecs_prt";

/* 试题类型-客观题 */
export const questionTypeList = [
  { value: "SINGLE_ANSWER_QUESTION", label: "单选" },
  { value: "MULTIPLE_ANSWER_QUESTION", label: "多选" },
  { value: "BOOL_ANSWER_QUESTION", label: "判断" }
];

/* 单独备份袋设置-归集类型 */
export const groupTypeList = [
  { value: "LEARN_CENTER", label: "学习中心" },
  { value: "EXAM_SITE", label: "考点" }
];

/* 考试课程的试卷状态 */
export const coursePaperStatusList = [
  { value: 0, label: "无" },
  { value: 1, label: "未指定" },
  { value: 2, label: "已有" }
];

/* 是否为空字符串 */
Vue.prototype.isEmptyStr = function(str) {
  if (str == undefined || String(str).length < 1) {
    return true;
  }
  return false;
};

/* 是否为空数字 */
Vue.prototype.isEmptyNumber = function(number) {
  let reg = /^[0-9]+$/;
  if (!reg.test(number)) {
    return true;
  }
  return false;
};

/* 日期格式处理 yyyy-MM-dd HH:mm:ss */
Vue.prototype.formatDateStr = function(dateStr) {
  if (!dateStr) {
    return "";
  }
  let date = new Date(dateStr);
  let year = date.getFullYear();
  let month = this.fillZero(date.getMonth() + 1);
  let day = this.fillZero(date.getDate());
  let hour = this.fillZero(date.getHours());
  let minute = this.fillZero(date.getMinutes());
  let second = this.fillZero(date.getSeconds());
  return (
    year + "-" + month + "-" + day + " " + hour + ":" + minute + ":" + second
  );
};

/* 个位数填充零 */
Vue.prototype.fillZero = function(num) {
  if (num < 10) {
    return "0" + num;
  }
  return num;
};

/* 用户角色信息 */
export const userRole = {
  /* 是否为印刷总负责人 */
  isSuperLeader: false,
  /* 是否为项目经理 */
  isPM: false,
  /* 是否为印刷供应商 */
  isSupplier: false,
  /* 是否为印刷学校管理员 */
  isSchoolLeader: false,
  /* 其它 */
  isOther: false
};

Vue.prototype.loadUserRole = function(loginUser) {
  let roles = loginUser.roleList;
  for (let role of roles) {
    let roleCode = role.roleCode;
    if (roleCode == "PRINT_SUPPLIER") {
      this.curUserRole.isSupplier = true;
    } else if (roleCode == "PRINT_SCHOOL_LEADER") {
      this.curUserRole.isSchoolLeader = true;
    } else if (roleCode == "PRINT_SUPER_LEADER") {
      this.curUserRole.isSuperLeader = true;
    } else if (roleCode == "PRINT_PROJECT_LEADER") {
      this.curUserRole.isPM = true;
    } else {
      this.curUserRole.isOther = true;
    }
  }
  //console.log("curUserRole:", this.curUserRole);
};

Vue.prototype.loadPmInfo = function(loginUser) {
  this.pmList = [];
  this.pmList.push({ id: loginUser.userId, name: loginUser.displayName });
};

Vue.prototype.loadSupplierInfo = function(loginUser) {
  this.supplierList = [];
  this.supplierList.push({ id: loginUser.userId, name: loginUser.displayName });
};

Vue.prototype.loadOrgList = function() {
  var url = PRINT_API + "/printing/project/org/list";
  this.$http.post(url).then(
    response => {
      this.orgList = response.data;
    },
    error => {
      console.log(error);
    }
  );
};
