import Vue from "vue";
import _ from "lodash";
import CKEditor from "@ckeditor/ckeditor5-vue";
export const QUESTION_API = "/api/ecs_ques"; //题库API
export const LEVEL_TYPE = [
  { label: "专升本", value: "ZSB" },
  { label: "高起专", value: "GQZ" },
  { label: "高起本", value: "GQB" },
  { label: "不限", value: "ALL" }
];
export const QUESTION_TYPES = [
  { value: "SINGLE_ANSWER_QUESTION", label: "单选" },
  { value: "MULTIPLE_ANSWER_QUESTION", label: "多选" },
  { value: "BOOL_ANSWER_QUESTION", label: "判断" },
  { value: "FILL_BLANK_QUESTION", label: "填空" },
  { value: "TEXT_ANSWER_QUESTION", label: "问答" },
  { value: "NESTED_ANSWER_QUESTION", label: "套题" }
];
export const PUBLICITY_LIST = [
  { label: "公开", value: true },
  { label: "非公开", value: false }
];
//option字母顺序过滤器
Vue.filter("optionOrderWordFilter", function(value) {
  return String.fromCharCode(65 + value);
});
//题型过滤器
Vue.filter("questionType", function(value) {
  for (let questionType of QUESTION_TYPES) {
    if (questionType.value === value) {
      return questionType.label;
    }
  }
});

export const EXAM_TYPES = [
  { value: "TRADITION", label: "传统考试" },
  { value: "ONLINE", label: "网络考试" },
  { value: "PRACTICE", label: "在线练习" }
];

export const EXPORT_TYPES = [
  { value: "ONLINE", label: "机考" },
  { value: "NORMAL", label: "普通" }
];

Vue.filter("examTypesFilter", function(value) {
  for (let item of EXAM_TYPES) {
    if (item.value === value) {
      return item.label;
    }
  }
});
Vue.filter("exportTypesFilter", function(value) {
  for (let item of EXPORT_TYPES) {
    if (item.value === value) {
      return item.label;
    }
  }
});

Vue.prototype._ = _;
Vue.use(CKEditor);

Vue.directive("questionAudio", {
  bind: function(el, binding, vnode) {
    addAudio(el, binding, vnode);
  }
});

function addAudio(el, binding, vnode) {
  // console.log(el, binding, vnode);
  var list = el.getElementsByTagName("a");
  for (let obj of list) {
    var questionAudioId = obj.getAttribute("id");
    if (questionAudioId) {
      console.log("come in");
      vnode.context.$http
        .get(QUESTION_API + "/questionAudio/" + questionAudioId)
        .then(response => {
          console.log("response:", response);
          if (response && response.data) {
            let audioFlag =
              '<audio controls><source src="http://exam-cloud-test.b0.upaiyun.com' +
              response.data.fileUrl +
              '" type="audio/mpeg"></audio>';
            var b = document.createElement("span");
            b.innerHTML = audioFlag;
            obj.append(b);
          }
        });
    }
  }
  console.log("el:", el);
}
